@@ -136,6 +136,7 @@ if(isset($_GET['action'])) {
                 if($rs[no_ring_disable]) $wa_ck1='checked';
                 if($rs[no_answer_disable]) $wa_ck2='checked';
                 if($rs[short_call_disable]) $wa_ck3='checked';
+		if($rs[count_limit_no_connect]) $ci_no_connect_ck='checked';
 
                 if($rs['remain_time']<0) $rs['remain_time'] = "";
 
@@ -165,8 +166,9 @@ if(isset($_GET['action'])) {
 		$sim_rs=$db->fetch_array($db->query("SELECT * FROM sim where sim_name='$sim_name'"));
 		if($sim_rs['time_limit']!=$_POST['time_limit']) $t_remain.=",remain_time=$_POST[time_limit]";
 		if($sim_rs['count_limit']!=$_POST['count_limit']) $t_remain.=",count_remain=$_POST[count_limit]";
+		if($sim_rs['limit_sms']!=$_POST['limit_sms']) $t_remain.=",remain_sms=$_POST[limit_sms]";
 		if($sim_rs['no_connected_limit']!=$_POST['no_connected_limit']) $t_remain.=",no_connected_remain=$_POST[no_connected_limit]";
-		$db->query("UPDATE sim SET imei_mode='$imei_mode', sim_team_id='$team_id',dev_disable='$dev_disable',plan_line_name='$_POST[line_name]',imei='$imei',time_limit='$_POST[time_limit]',time_unit='$time_unit',no_ring_limit='$_POST[no_ring_limit]',no_answer_limit='$_POST[no_answer_limit]',short_call_limit='$_POST[short_call_limit]',short_time='$_POST[short_time]',no_ring_disable='$_POST[no_ring_disable]',no_answer_disable='$_POST[no_answer_disable]',short_call_disable='$_POST[short_call_disable]',count_limit='$_POST[count_limit]',no_connected_limit='$_POST[no_connected_limit]',auto_reset_remain='$auto_reset_remain',auto_reset_remain_s='$auto_reset_remain_s' $t_remain WHERE sim_name='$sim_name'");
+		$db->query("UPDATE sim SET imei_mode='$imei_mode', sim_team_id='$team_id',dev_disable='$dev_disable',plan_line_name='$_POST[line_name]',imei='$imei',time_limit='$_POST[time_limit]',time_unit='$time_unit',no_ring_limit='$_POST[no_ring_limit]',no_answer_limit='$_POST[no_answer_limit]',short_call_limit='$_POST[short_call_limit]',short_time='$_POST[short_time]',no_ring_disable='$_POST[no_ring_disable]',no_answer_disable='$_POST[no_answer_disable]',short_call_disable='$_POST[short_call_disable]',count_limit='$_POST[count_limit]',no_connected_limit='$_POST[no_connected_limit]',auto_reset_remain='$auto_reset_remain',auto_reset_remain_s='$auto_reset_remain_s',count_limit_no_connect='$_POST[count_limit_no_connect]',limit_sms='$_POST[limit_sms]' $t_remain WHERE sim_name='$sim_name'");
 
 
 		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_name='$sim_name'");
@@ -228,6 +230,7 @@ if(isset($_GET['action'])) {
 		$where=gen_sim_where();
 		if($remain_time == "" || $remain_time < -1) $remain_time=-1;
 		if($_POST[time_limit] == "" || $_POST[time_limit] < -1) $_POST[time_limit]=-1;
+		if($_POST[limit_sms] == "" || $_POST[limit_sms] < -1) $_POST[limit_sms]=-1;
                 if($_POST[no_ring_limit] == "" || $_POST[no_ring_limit] < -1) $_POST[no_ring_limit]=-1;
                 if($_POST[no_answer_limit] == "" || $_POST[no_answer_limit] < -1) $_POST[no_answer_limit]=-1;
                 if($_POST[short_call_limit] == "" || $_POST[short_call_limit] < -1) $_POST[short_call_limit]=-1;
@@ -245,6 +248,8 @@ if(isset($_GET['action'])) {
 			if($_POST['imei_mode_modify']) $sql.="imei_mode='$imei_mode',";
 			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',remain_time='$_POST[time_limit]',";
 			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',count_remain=$_POST[count_limit],";
+			if($_POST['limit_sms_modify']) $sql.="limit_sms='$_POST[limit_sms]',remain_sms='$_POST[limit_sms]',";
+			if($_POST['count_limit_no_connect_modify']) $sql.="count_limit_no_connect='$_POST[count_limit_no_connect]',";
 			if($_POST['no_connected_limit_modify']) $sql.="no_connected_limit='$_POST[no_connected_limit]',no_connected_remain=$_POST[no_connected_limit],";
 			if($_POST['time_unit_modify']) $sql.="time_unit='$time_unit',";
 			if($_POST['no_ring_modify']) $sql.="no_ring_limit='$_POST[no_ring_limit]',no_ring_disable='$_POST[no_ring_disable]',";
@@ -284,7 +289,8 @@ if(isset($_GET['action'])) {
 
 		$where=gen_sim_where();
 
-		$db->query("update sim set no_ring_remain=0,no_answer_remain=0,short_call_remain=0,remain_time=time_limit,count_remain=count_limit,no_connected_remain=no_connected_limit $where");
+		$db->query("update sim set no_ring_remain=0,no_answer_remain=0,short_call_remain=0,remain_time=time_limit,remain_sms
+=limit_sms,count_remain=count_limit,no_connected_remain=no_connected_limit $where");
 
 		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name $where");
 		while($row=$db->fetch_array($query)) {
@@ -448,18 +454,20 @@ if(isset($_GET['action'])) {
 			$row['remain_limit']="total remain time: ".$row['remain_time']."/".$row['time_limit']."\n";
                         $row['remain_limit'].="total remain count: ".$row['count_remain']."/".$row['count_limit']."\n";
                         $row['remain_limit'].="total remain no connected count: ".$row['no_connected_remain']."/".$row['no_connected_limit']."\n";
+			$row['remain_limit'].="total remain SMS: ".$row['remain_sms']."/".$row['limit_sms']."\n";
 			$row['remain_limit'].="period remain time: ".$row['period_time_remain']."\n";
-			$row['remain_limit'].="period remain count: ".$row['period_count_remain']."";
+			$row['remain_limit'].="period remain count: ".$row['period_count_remain']."\n";
+			$row['remain_limit'].="period remain SMS: ".$row['period_remain_sms']."";
 			
 			$row['limit_title']="no ring consecutive count: ".$row['no_ring_remain']."/".$row['no_ring_limit']."\n";
 			$row['limit_title'].="no answer consecutive count: ".$row['no_answer_remain']."/".$row['no_answer_limit']."\n";
 			$row['limit_title'].="short call consecutive count: ".$row['short_call_remain']."/".$row['short_call_limit']."";
 			
 			$row['remain_state'] = '<font color="#00FF00">Enough</font>';
-			if($row['remain_time']==0 || $row['period_time_remain']==0 || $row['period_count_remain']==0 || $row['count_remain']==0 || $row['no_connected_remain']==0){
+			if($row['remain_time']==0 || $row['period_time_remain']==0 || $row['period_count_remain']==0 || $row['count_remain']==0 || $row['no_connected_remain']==0 || $row['remain_sms']==0 || $row['period_remain_sms']==0){
 				$row['remain_state'] = '<font color="#FF0000">Exhaust</font>';
 			}
-			else if(($row['remain_time']<=$limit_t_w && $row['remain_time']!=-1) || ($row['period_time_remain']<=$limit_t_w && $row['period_time_remain']!=-1)|| ($row['period_count_remain']<=$limit_c_w && $row['period_count_remain']!=-1) || ($row['count_remain']<=$limit_c_w && $row['count_remain']!=-1) || ($row['no_connected_remain']<=$limit_c_w && $row['no_connected_remain']!=-1)){
+			else if(($row['remain_time']<=$limit_t_w && $row['remain_time']!=-1) || ($row['period_time_remain']<=$limit_t_w && $row['period_time_remain']!=-1)|| ($row['period_count_remain']<=$limit_c_w && $row['period_count_remain']!=-1) || ($row['count_remain']<=$limit_c_w && $row['count_remain']!=-1) || ($row['no_connected_remain']<=$limit_c_w && $row['no_connected_remain']!=-1) || ($row['remain_sms']<=$limit_c_w && $row['remain_sms']!=-1) || ($row['period_remain_sms']<=$limit_c_w && $row['period_remain_sms']!=-1)){
 				$row['remain_state'] = '<font color="#FF8000">Warning</font>';
 			}
 			$row['limit_state'] = '<font color="#00FF00">Enough</font>';
