@@ -388,6 +388,19 @@
 		@$db->updatequery("update `system` set `version`='112'");
 	}
 
+
+/*
+	for($i=1;$i<=100;$i++){
+			$name="dbl".$i;
+                        $db->query("INSERT INTO `sim_team` (sim_team_name) value ('$name') ");
+                        $groupiddb=$db->fetch_array($db->query("SELECT LAST_INSERT_ID()"));
+                        $groupid=$groupiddb[0];
+                        $db->query("INSERT INTO `scheduler` (name,group_id,type) value ('$name', '$groupid','cycle') ");
+                        $schiddb=$db->fetch_array($db->query("SELECT LAST_INSERT_ID()"));
+                        $schid=$schiddb[0];
+                        $db->query("update sim_team set scheduler_id='$schid' where sim_team_id='$groupid'");
+	}
+*/
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 ?>
